@@ -1,5 +1,14 @@
+#
+# This file is part of Template-Plugin-Next
+#
+# This software is copyright (c) 2017 by Alexander Kühne.
+#
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
+#
 package Template::Plugin::Next;
-
+# ABSTRACT: include the 'next' template file with identical relative path
+$Template::Plugin::Next::VERSION = '0.04';
 use warnings;
 use strict;
 
@@ -9,65 +18,6 @@ use Template::Exception ();
 
 use File::Spec ();
 
-use 5.006;
-
-=head1 NAME
-
-Template::Plugin::Next - include the 'next' template file with identical relative path
-
-=head1 VERSION
-
-Version 0.03
-
-=cut
-
-our $VERSION = '0.03';
-
-
-=head1 SYNOPSIS
-
-This is a plugin for the Template Toolkit distribution that allows the inclusion of template files with identical relative paths like the present template. Those templates are 'hidden' by the present template, because their respective INCLUDE_PATH entries are dominated by the one of the including template.
-
-The functionality provided by this plugin might come handy in multi skin situations where default templates are selectively redefined by a skin using a dominating INCLUDE_PATH entry for the skin and identical relative paths to the templates as with the default templates - thus hiding them. 
-
-The Next-plugin allows to include the dominated default templates from inside the hiding template in order to decorate the default template or include a parameterized version of it. 
-
-Example:
-
-  # We assume: INCLUDE_PATH='/templates/c:/templates/b:/templates/a'
-
-  # template a/test.tt (note this template accepts a "parameter" called 'repeat'):
-  [% repeat = repeat || 1; 'a' | repeat(repeat) %]
-  
-  # template b/test.tt:
-  b
-  [% USE Next; Next.include( repeat => 3 ); %]
-  b
-  
-  # template c/test.tt:
-  c
-  [% USE Next; Next.include(); %]
-  c
-
-  # a call to template test.tt
-  [% INCLUDE test.tt %]
-  
-  # would yield something like the following (with POST_CHOMP set to 1):
-  
-  c
-  b
-  aaa
-  b
-  c
-
-
-=head1 EXPORT
-
-Exported stash variable: Next_
-
-=head1 METHODS
-
-=cut
 
 sub new {      
     # called as Template::Plugin::Next->new($context)
@@ -86,11 +36,6 @@ sub error {
     die( ref( $_[0] ) ? @_ : do { $proto->SUPER::error(@_); Template::Exception->new( 'Next', $proto->SUPER::error ) } );
 }
 
-=head2 process
-
-Includes the 'next' dominated template with an identical relative path like the one this plugin method is called from. It accepts named parameters like its TT directive counterpart PROCESS that will result in stash variables.
-
-=cut
 
 sub process {
     my $self = shift;
@@ -157,11 +102,6 @@ sub process {
     $self->error( "No 'Next' template!" );
 }
 
-=head2 include
-
-Same as process() but with stash localisation. 
-
-=cut
 
 sub include {
     my $self = shift;
@@ -185,6 +125,73 @@ sub _concat_path {
     );
 }
 
+
+1; # End of Template::Plugin::Next
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Template::Plugin::Next - include the 'next' template file with identical relative path
+
+=head1 VERSION
+
+version 0.04
+
+=head1 SYNOPSIS
+
+This is a plugin for the Template Toolkit distribution that allows the inclusion of template files with identical relative paths like the present template. Those templates are 'hidden' by the present template, because their respective INCLUDE_PATH entries are dominated by the one of the including template.
+
+The functionality provided by this plugin might come handy in multi skin situations where default templates are selectively redefined by a skin using a dominating INCLUDE_PATH entry for the skin and identical relative paths to the templates as with the default templates - thus hiding them. 
+
+The Next-plugin allows to include the dominated default templates from inside the hiding template in order to decorate the default template or include a parameterized version of it. 
+
+Example:
+
+  # We assume: INCLUDE_PATH='/templates/c:/templates/b:/templates/a'
+
+  # template a/test.tt (note this template accepts a "parameter" called 'repeat'):
+  [% repeat = repeat || 1; 'a' | repeat(repeat) %]
+  
+  # template b/test.tt:
+  b
+  [% USE Next; Next.include( repeat => 3 ); %]
+  b
+  
+  # template c/test.tt:
+  c
+  [% USE Next; Next.include(); %]
+  c
+
+  # a call to template test.tt
+  [% INCLUDE test.tt %]
+  
+  # would yield something like the following (with POST_CHOMP set to 1):
+  
+  c
+  b
+  aaa
+  b
+  c
+
+=head1 EXPORT
+
+Exported stash variable: Next_
+
+=head1 METHODS
+
+=head2 process
+
+Includes the 'next' dominated template with an identical relative path like the one this plugin method is called from. It accepts named parameters like its TT directive counterpart PROCESS that will result in stash variables.
+
+=head2 include
+
+Same as process() but with stash localisation. 
+
 =head1 CAVEATS
 
 =over 4 
@@ -195,26 +202,18 @@ sub _concat_path {
 
 =back
 
-=head1 AUTHOR
-
-Alexander Khne, C<< <alexk at cpan.org> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-template-plugin-next at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Template-Plugin-Next>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Template::Plugin::Next
 
-
 You can also look for information at:
 
 =over 4
@@ -237,14 +236,15 @@ L<http://search.cpan.org/dist/Template-Plugin-Next/>
 
 =back
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2010 Alexander Khne, all rights reserved.
+Alexander Kühne <alexk@cpan.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2017 by Alexander Kühne.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1; # End of Template::Plugin::Next
